@@ -2044,7 +2044,7 @@ class Catalog {
 		$genre 		= $results['genre'];
 		$bitrate 	= $results['bitrate'];
 		$rate	 	= $results['rate'];
-		$mode 		= $results['mode'];
+		$mode 		= ($results['mode'] == 'cbr') ? 'cbr' : 'vbr'; 
 		$size	 	= $results['size'];
 		$song_time 	= $results['time'];
 		$track	 	= $results['track'];
